##  Fact Sheet Comments
Event | Description
---|---
COMMENT_CREATED | A comment is created on a fact sheet.
COMMENT_REPLY_ADDED | A reply is added to a comment on a fact sheet.
COMMENT_DELETED | A comment is deleted from a fact sheet.


